# Jobs

Types:

```python
from rainbows.types import JobSearchResponse
```

Methods:

- <code title="post /jobs/search">client.jobs.<a href="./src/rainbows/resources/jobs.py">search</a>(\*\*<a href="src/rainbows/types/job_search_params.py">params</a>) -> <a href="./src/rainbows/types/job_search_response.py">JobSearchResponse</a></code>
